cocos 0.6.5 — cocos v0.6.5 documentation

Api changes and other compatibility notes

# cocos 0.6.5

> - First cocos version to support pyglet 1.3 , tested against pyglet 1.3.rc1
> - This cocos version can also run with pyglet 1.2.x
> - Next cocos version will drop support for python 2.6
> - Python 2.7 support can end at any future cocos release, without further advice: if pyglet drops it or a cocos new feature requires more than trivial compatibility code, then cocos will be py3 only

# cocos 0.6.4

Imports in cocos library are more specific, so user code that were doing `from cocos.somemodule import *` may fail to find some symbols. To fix that user code, add explicit exports as needed.

MapColliders classes changed API to be more useful and clear.
  - `RectMapCollider` moved to his own module, `mapcolliders`.
  - `RectMapCollider` was renamed to `RectMapWithPropsCollider`.
  - The new `RectMapCollider` handles a simpler collision case, when all tiles are solid: now no need to set cells properties to signal a cell border should not be walked over.
  - `TmxObjectMapCollider` now handles AABB collision with any `TmxObject` that can be loaded.

`Rect.intersects()` now it only intersects if some interior points overlaps.

Removed `Scene` methods `push_all_handlers()` and `remove_all_handlers()`.

In `ScrollingManager` two methods have been renamed, the old name is still valid but will be removed in the future:

> - `pixel_from_screen()` -> `screen_to_world()`
> - `pixel_to_screen()` -> `world_to_screen()`